window.onload = function () {
    // Fetch JSON data from the provided URL
    fetch('https://gist.githubusercontent.com/yuting89830/329026a9d25489f9841b0c3467671a21/raw/01ea409df6c76492590fec31f809d56ea1744f99/taipower.json')
        .then(response => response.json())
        .then(data => {
            // Call function to convert JSON data to a table
            createHourlyTrendTable(data);
        })
        .catch(error => console.error('Error fetching data:', error));
};

function createHourlyTrendTable(data) {
    const table = document.getElementById('data-table');
    
    // Call function to calculate hourly usage trend
    const diffTrend = calcDiffTrend(data);

    // Create table header
    let headerRow = table.insertRow();
    let headerCell = document.createElement('th');
    headerCell.textContent = '時間';
    headerRow.appendChild(headerCell);

    // Extract and add date headers
    for (const date in diffTrend) {
        headerCell = document.createElement('th');
        headerCell.textContent = date;
        headerRow.appendChild(headerCell);
    }

    // Add table rows with hourly trend data
    for (const hourMinute in diffTrend[Object.keys(diffTrend)[0]]) {
        const row = table.insertRow();
        let cell = row.insertCell();
        cell.textContent = hourMinute;

        for (const date in diffTrend) {
            cell = row.insertCell();
            cell.textContent = diffTrend[date][hourMinute] || 0;
        }
    }
}

function calcDiffTrend(data) {
    const limitDateNum = 14;
    const today = parseInt(moment(moment().format('YYYY-MM-DD')).format('x'));
    const tomorraw = parseInt(moment(today).add(1, 'days').format('x'));
    const startDate = moment(today).add((limitDateNum * -1 + 1), 'days').format('YYYY-MM-DD');
    const startDateTimestamp = parseInt(moment(startDate).format('x'));

    const mappingShowWeek = {};
    const thisWeekNum = moment().format('ww');

    for (let dateIndex = 0; dateIndex < limitDateNum; dateIndex += 1) {
        const timestamp = startDateTimestamp + (dateIndex) * 86400000;
        const dateObj = moment(timestamp);
        const date = dateObj.format('YYYY-MM-DD');
        let showWeek = dateObj.format('ddd');
        const weekNum = dateObj.format('ww');
        for (let i = 0; i < (thisWeekNum - weekNum); i += 1) {
            showWeek = `上${showWeek}`;
        }
        mappingShowWeek[date] = showWeek;
    }

    const diffTrend = {};
    const nowTimestamp = moment(moment().format('YYYY-MM-DD HH:mm:00')).format('x') - 600000;
    for (let i = today; i < tomorraw; i += 600000) {
        const hourMinute = moment(i).format('HH:mm');
        diffTrend[hourMinute] = {};

        for (let dateIndex = 0; dateIndex < limitDateNum; dateIndex += 1) {
            const date = moment(startDateTimestamp + dateIndex * 86400000).format('YYYY-MM-DD');
            let used = false;
            const dateTime = `${date} ${hourMinute}`;

            if (moment(`${dateTime}:00`).format('x') < nowTimestamp) {
                used = 0;
                if (data[dateTime]) {
                    const info = JSON.parse(JSON.stringify(data[`${date} ${hourMinute}`]));
                    for (const typeKey in info) {
                        if (!!info[typeKey] && 1) {
                            used += parseFloat(info[typeKey].used);
                        }
                    }
                }
            }

            if (used !== false) {
                const showWeek = mappingShowWeek[date];
                diffTrend[hourMinute][showWeek] = Math.round(used * 100) / 100;
            }
        }
    }
    return diffTre